"""
(c) Copyright 2015 Hexoskin
Permission to use, copy, modify, and distribute this software for any purpose with or without fee is hereby granted,
provided that the above copyright notice and this permission notice appear in all copies. The software is provided
"as is" and the author disclaims all warranties with regard to this software including all implied warranties of
merchantability and fitness. In no event shall the author be liable for any special, direct, indirect, or
consequential damages or any damages whatsoever resulting from loss of use, data or profits, whether in an action of
contract, negligence or other tortious action, arising out of or in connection with the use or performance of this
software.

ConvertSourceFile.py
    This code demonstrates and implements the decoding of binary data
    as downloaded from the my.hexoskin.com dashboard. Datas are downloaded in
    binary (wav) and CSV format from the dashboard. The code converts them to
    a more "human-friendly" format, then saves it as a CSV in the same
    folder.
    See "convert_raw_data.load_data" can be used direclty in python to load data in an array of float

    Call python convertSourceFile.py -h for help on options
"""

import argparse
import os
import json

from convert_raw_data import VERSION, convert_directory


def check_version(directory):
    with open(os.path.join(directory, "info.json"), "r") as f:
        info = json.load(f)
    file_version = [int(a) for a in info['decoder_version'].split('.')]
    if VERSION < file_version:
        raise AssertionError("Decoder version {}  too old. redownload decoder at: "
                             "'http://support.hexoskin.com/customer/portal/articles/1758581-how-do-i-convert-binary-"
                             "data-downloaded-from-the-dashboard-'\n".format(VERSION))


def main():
    help_text = '''
                This program converts the binary data from the Hexoskin system to CSV format.
                The program start a GUI if no argument is passed.
                '''

    parser = argparse.ArgumentParser(description=help_text)
    parser.add_argument('path', action='store', type=str, nargs='?',
                        help='The filepath from which to get the data to convert from. No filepath will start a GUI')
    parser.add_argument('-addquality', action='store_true',
                        help='Add quality status to heartrate and breathingrate instead of putting them in separate files ',
                        ),
    parser.add_argument('-group', action='store_true',
                        help='Group 1 Hz data in outputData.csv instead of outputting them in different files',
                        ),
    parser.add_argument('-group_raw', action='store_true',
                        help='Group raw data in outputDataRaw.csv instead of outputting them in different files',
                        ),
    parser.add_argument('-epoch', action='store_true',
                        help='Save in Posix epoch time. (seconds since 1 January 1970) ',
                        )
    parser.add_argument('-noheader', action='store_true',
                        help="Don't save header",
                        )
    parser.add_argument('-skip_raw', action='store_true',
                        help="Skip raw data (with frequency over 1  Hz)",
                        )
    parser.add_argument('-as_nan', action='store_true',
                        help="Replace empty values by nan",
                        )
    parser.add_argument('-with_tab', action='store_true',
                        help="separate by tab and not comma",
                        )
    args = parser.parse_args()
    if args.path is None:
        from gui_convertSourceFile import run_GUI

        print('-----------------')
        print('GUI launched, for help run with option -h')
        print('-----------------\n')
        run_GUI()
    else:
        settings = dict(
            add_quality=args.addquality,
            group=args.group,
            group_raw=args.group_raw,
            epoch=args.epoch,
            header=not args.noheader,
            skip_raw=args.skip_raw,
            as_nan=args.as_nan,
            delimiter_tab=args.with_tab
        )
        try:
            convert_directory(args.path, settings)
        except Exception as e:
            print(e)


if __name__ == "__main__":
    main()
